@@ -1,4 +1,4 @@
-create table #dblib0016 (id int not null, var uniqueidentifier null, c1 xml null)
+create table #dblib0016 (id int not null, var uniqueidentifier null, c1 nvarchar(200))
 go
 select * from #dblib0016 where 0=1
 go
